@@ -39,9 +39,21 @@ def create_examples(
     """ Serialize each input raw data into examples. """
     
     if labels:
-        labels = [config.label2id[label] for label in labels]
-        examples = [InputExample(text=text, label=label) \
-        for text, label in zip(texts, labels)]
+        if get_nesting_level(labels)==1:
+            labels = [config.label2id[label] for label in labels]
+            examples = [
+                InputExample(text=text, label=label)
+                for text, label in zip(texts, labels)
+            ]
+        elif get_nesting_level(labels)==2:
+            labels = [
+                [config.label2id[label] for label in sub_labels] 
+                for sub_labels in labels
+            ]
+            examples = [
+                InputExample(text=text, label=label)
+                for text, label in zip(texts, labels)
+            ]
     else:
         examples = [InputExample(text=text) for text in texts]
         
@@ -52,9 +64,11 @@ def split_examples(
     examples: List[InputExample],
     train_frac: float = None,
     test_frac: float = None, 
-    shufffle: bool = True, 
+    shufffle: bool = True,
+    random_seed: int = 42,
    ) -> Tuple[InputExample]:
-    """  """
+    """ split the input example into a training and a
+    testing set. """
     
     n_examples = len(examples)
     n_train = int(np.ceil(n_examples*train_frac))
@@ -62,16 +76,17 @@ def split_examples(
     n_total = n_train + n_test
     
     if shufffle:
-        order = np.random.permutation(n_examples)
-        train_idx = order[n_train:]
-        test_idx = order[:n_test]
+        random_state = np.random.RandomState(random_seed)
+        order = random_state.permutation(n_examples)
+        train_idx = order[:n_train]
+        test_idx = order[n_train:n_total]
     else:
         train_idx = np.arange(n_train)
         test_idx = np.arange(n_train, n_total)
     
     train_examples = [examples[idx] for idx in train_idx]
     test_examples = [examples[idx] for idx in test_idx]
-        
+    
     return train_examples, test_examples
 
 
@@ -93,3 +108,13 @@ def generate_batches(
         yield X_batch, Y_batch    
         X_batch = list()
         Y_batch = list()
+
+
+def get_nesting_level(maybe_nested_labels):
+    max_level = 1
+    for element in maybe_nested_labels:
+        if isinstance(element, list):
+            level = get_labels_type(element)
+            if level > max_level:
+                max_level = level
+    return max_level
